@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -33,11 +33,9 @@
 #include <unistd.h>
 #endif /* HAVE_UNISTD_H */
 #include <glib/gi18n.h>
-#include <gconf/gconf-client.h>
 #include <packagekit-glib2/packagekit.h>
-#include <devkit-power-gobject/devicekit-power.h>
+#include <libupower-glib/upower.h>
 
-#include "egg-debug.h"
 #include "egg-string.h"
 
 #include "gpk-common.h"
@@ -66,8 +64,9 @@ struct GpkAutoRefreshPrivate
 	gboolean		 force_get_updates_login;
 	guint			 force_get_updates_login_timeout_id;
 	guint			 timeout_id;
-	DkpClient		*client;
-	GConfClient		*gconf_client;
+	guint			 periodic_id;
+	UpClient		*client;
+	GSettings		*settings;
 	GpkSession		*session;
 	PkControl		*control;
 };
@@ -118,7 +117,7 @@ gpk_auto_refresh_signal_refresh_cache (GpkAutoRefresh *arefresh)
 {
 	g_return_val_if_fail (GPK_IS_AUTO_REFRESH (arefresh), FALSE);
 
-	egg_debug ("emitting refresh-cache");
+	g_debug ("emitting refresh-cache");
 	g_signal_emit (arefresh, signals [REFRESH_CACHE], 0);
 	return TRUE;
 }
@@ -131,7 +130,7 @@ gpk_auto_refresh_signal_get_updates (GpkAutoRefresh *arefresh)
 {
 	g_return_val_if_fail (GPK_IS_AUTO_REFRESH (arefresh), FALSE);
 
-	egg_debug ("emitting get-updates");
+	g_debug ("emitting get-updates");
 	g_signal_emit (arefresh, signals [GET_UPDATES], 0);
 	return TRUE;
 }
@@ -144,32 +143,11 @@ gpk_auto_refresh_signal_get_upgrades (GpkAutoRefresh *arefresh)
 {
 	g_return_val_if_fail (GPK_IS_AUTO_REFRESH (arefresh), FALSE);
 
-	egg_debug ("emitting get-upgrades");
+	g_debug ("emitting get-upgrades");
 	g_signal_emit (arefresh, signals [GET_UPGRADES], 0);
 	return TRUE;
 }
 
-/**
- * gpk_auto_refresh_get_frequency_prefs:
- **/
-static guint
-gpk_auto_refresh_get_frequency_prefs (GpkAutoRefresh *arefresh, const gchar *key)
-{
-	guint value;
-
-	g_return_val_if_fail (GPK_IS_AUTO_REFRESH (arefresh), 0);
-
-	/* get from gconf */
-	value = gconf_client_get_int (arefresh->priv->gconf_client, key, NULL);
-	if (value == 0) {
-		egg_warning ("no schema for %s, using daily", key);
-		value = 86400;
-	}
-
-	/* convert to enum and get seconds */
-	return value;
-}
-
 /**
  * gpk_auto_refresh_get_time_refresh_cache_cb:
  **/
@@ -184,15 +162,15 @@ gpk_auto_refresh_get_time_refresh_cache_cb (GObject *object, GAsyncResult *res,
 	/* get the result */
 	seconds = pk_control_get_time_since_action_finish (control, res, &error);
 	if (seconds == 0) {
-		egg_warning ("failed to get time: %s", error->message);
+		g_warning ("failed to get time: %s", error->message);
 		g_error_free (error);
 		return;
 	}
 
 	/* have we passed the timout? */
-	thresh = gpk_auto_refresh_get_frequency_prefs (arefresh, GPK_CONF_FREQUENCY_GET_UPDATES);
+	thresh = g_settings_get_int (arefresh->priv->settings, GPK_SETTINGS_FREQUENCY_GET_UPDATES);
 	if (seconds < thresh) {
-		egg_debug ("not before timeout, thresh=%u, now=%u", thresh, seconds);
+		g_debug ("not before timeout, thresh=%u, now=%u", thresh, seconds);
 		return;
 	}
 
@@ -211,28 +189,28 @@ gpk_auto_refresh_maybe_refresh_cache (GpkAutoRefresh *arefresh)
 	g_return_if_fail (GPK_IS_AUTO_REFRESH (arefresh));
 
 	/* if we don't want to auto check for updates, don't do this either */
-	thresh = gpk_auto_refresh_get_frequency_prefs (arefresh, GPK_CONF_FREQUENCY_GET_UPDATES);
+	thresh = g_settings_get_int (arefresh->priv->settings, GPK_SETTINGS_FREQUENCY_GET_UPDATES);
 	if (thresh == 0) {
-		egg_debug ("not when policy is to never get updates");
+		g_debug ("not when policy is set to never");
 		return;
 	}
 
 	/* not on battery */
 	if (arefresh->priv->on_battery) {
-		egg_debug ("not when on battery");
+		g_debug ("not when on battery");
 		return;
 	}
 
 	/* only do the refresh cache when the user is idle */
 	if (!arefresh->priv->session_idle) {
-		egg_debug ("not when session active");
+		g_debug ("not when session active");
 		return;
 	}
 
 	/* get this each time, as it may have changed behind out back */
-	thresh = gpk_auto_refresh_get_frequency_prefs (arefresh, GPK_CONF_FREQUENCY_REFRESH_CACHE);
+	thresh = g_settings_get_int (arefresh->priv->settings, GPK_SETTINGS_FREQUENCY_REFRESH_CACHE);
 	if (thresh == 0) {
-		egg_debug ("not when policy is to never refresh");
+		g_debug ("not when policy is set to never");
 		return;
 	}
 
@@ -255,15 +233,15 @@ gpk_auto_refresh_get_time_get_updates_cb (GObject *object, GAsyncResult *res, Gp
 	/* get the result */
 	seconds = pk_control_get_time_since_action_finish (control, res, &error);
 	if (seconds == 0) {
-		egg_warning ("failed to get time: %s", error->message);
+		g_warning ("failed to get time: %s", error->message);
 		g_error_free (error);
 		return;
 	}
 
 	/* have we passed the timout? */
-	thresh = gpk_auto_refresh_get_frequency_prefs (arefresh, GPK_CONF_FREQUENCY_GET_UPDATES);
+	thresh = g_settings_get_int (arefresh->priv->settings, GPK_SETTINGS_FREQUENCY_GET_UPDATES);
 	if (seconds < thresh) {
-		egg_debug ("not before timeout, thresh=%u, now=%u", thresh, seconds);
+		g_debug ("not before timeout, thresh=%u, now=%u", thresh, seconds);
 		return;
 	}
 
@@ -283,17 +261,17 @@ gpk_auto_refresh_maybe_get_updates (GpkAutoRefresh *arefresh)
 
 	if (!arefresh->priv->force_get_updates_login) {
 		arefresh->priv->force_get_updates_login = TRUE;
-		if (gconf_client_get_bool (arefresh->priv->gconf_client, GPK_CONF_FORCE_GET_UPDATES_LOGIN, NULL)) {
-			egg_debug ("forcing get update due to GConf");
+		if (g_settings_get_boolean (arefresh->priv->settings, GPK_SETTINGS_FORCE_GET_UPDATES_LOGIN)) {
+			g_debug ("forcing get update due to GSettings");
 			gpk_auto_refresh_signal_get_updates (arefresh);
 			return;
 		}
 	}
 
 	/* if we don't want to auto check for updates, don't do this either */
-	thresh = gpk_auto_refresh_get_frequency_prefs (arefresh, GPK_CONF_FREQUENCY_GET_UPDATES);
+	thresh = g_settings_get_int (arefresh->priv->settings, GPK_SETTINGS_FREQUENCY_GET_UPDATES);
 	if (thresh == 0) {
-		egg_debug ("not when policy is to never get updates");
+		g_debug ("not when policy is set to never");
 		return;
 	}
 
@@ -316,15 +294,15 @@ gpk_auto_refresh_get_time_get_upgrades_cb (GObject *object, GAsyncResult *res, G
 	/* get the result */
 	seconds = pk_control_get_time_since_action_finish (control, res, &error);
 	if (seconds == 0) {
-		egg_warning ("failed to get time: %s", error->message);
+		g_warning ("failed to get time: %s", error->message);
 		g_error_free (error);
 		return;
 	}
 
 	/* have we passed the timout? */
-	thresh = gpk_auto_refresh_get_frequency_prefs (arefresh, GPK_CONF_FREQUENCY_GET_UPDATES);
+	thresh = g_settings_get_int (arefresh->priv->settings, GPK_SETTINGS_FREQUENCY_GET_UPDATES);
 	if (seconds < thresh) {
-		egg_debug ("not before timeout, thresh=%u, now=%u", thresh, seconds);
+		g_debug ("not before timeout, thresh=%u, now=%u", thresh, seconds);
 		return;
 	}
 
@@ -343,9 +321,9 @@ gpk_auto_refresh_maybe_get_upgrades (GpkAutoRefresh *arefresh)
 	g_return_if_fail (GPK_IS_AUTO_REFRESH (arefresh));
 
 	/* get this each time, as it may have changed behind out back */
-	thresh = gpk_auto_refresh_get_frequency_prefs (arefresh, GPK_CONF_FREQUENCY_GET_UPGRADES);
+	thresh = g_settings_get_int (arefresh->priv->settings, GPK_SETTINGS_FREQUENCY_GET_UPGRADES);
 	if (thresh == 0) {
-		egg_debug ("not when policy is set to never check for upgrades");
+		g_debug ("not when policy is set to never");
 		return;
 	}
 
@@ -391,49 +369,54 @@ gpk_auto_refresh_change_state (GpkAutoRefresh *arefresh)
 
 	/* no point continuing if we have no network */
 	if (!arefresh->priv->network_active) {
-		egg_debug ("not when no network");
+		g_debug ("not when no network");
 		return FALSE;
 	}
 
 	/* only force a check if the user REALLY, REALLY wants to break
 	 * set policy and have an update at startup */
 	if (!arefresh->priv->force_get_updates_login) {
-		force = gconf_client_get_bool (arefresh->priv->gconf_client, GPK_CONF_FORCE_GET_UPDATES_LOGIN, NULL);
+		force = g_settings_get_boolean (arefresh->priv->settings, GPK_SETTINGS_FORCE_GET_UPDATES_LOGIN);
 		if (force) {
 			/* don't immediately send the signal, if we are called during object initialization
 			 * we need to wait until upper layers  finish hooking up to the signal first. */
-			if (arefresh->priv->force_get_updates_login_timeout_id == 0)
+			if (arefresh->priv->force_get_updates_login_timeout_id == 0) {
 				arefresh->priv->force_get_updates_login_timeout_id =
-					g_timeout_add_seconds (GPK_UPDATES_LOGIN_TIMEOUT, (GSourceFunc) gpk_auto_refresh_maybe_get_updates_logon_cb, arefresh);
+					g_timeout_add_seconds (GPK_UPDATES_LOGIN_TIMEOUT,
+							       (GSourceFunc) gpk_auto_refresh_maybe_get_updates_logon_cb,
+							       arefresh);
+				g_source_set_name_by_id (arefresh->priv->force_get_updates_login_timeout_id,
+							 "[GpkAutoRefresh] maybe-get-updates");
+			}
 		}
 	}
 
 	/* wait a little time for things to settle down */
 	if (arefresh->priv->timeout_id != 0)
 		g_source_remove (arefresh->priv->timeout_id);
-	value = gconf_client_get_int (arefresh->priv->gconf_client, GPK_CONF_SESSION_STARTUP_TIMEOUT, NULL);
-	egg_debug ("defering action for %i seconds", value);
-	arefresh->priv->timeout_id = g_timeout_add_seconds (value, (GSourceFunc) gpk_auto_refresh_change_state_cb, arefresh);
+	value = g_settings_get_int (arefresh->priv->settings, GPK_SETTINGS_SESSION_STARTUP_TIMEOUT);
+	g_debug ("defering action for %i seconds", value);
+	arefresh->priv->timeout_id =
+		g_timeout_add_seconds (value, (GSourceFunc) gpk_auto_refresh_change_state_cb, arefresh);
+	g_source_set_name_by_id (arefresh->priv->timeout_id, "[GpkAutoRefresh] change-state");
 
 	return TRUE;
 }
 
 /**
- * gpk_auto_refresh_gconf_key_changed_cb:
- *
- * We might have to do things when the gconf keys change; do them here.
+ * gpk_auto_refresh_key_changed_cb:
  **/
 static void
-gpk_auto_refresh_gconf_key_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, GpkAutoRefresh *arefresh)
+gpk_auto_refresh_key_changed_cb (GSettings *client, const gchar *key, GpkAutoRefresh *arefresh)
 {
 	g_return_if_fail (GPK_IS_AUTO_REFRESH (arefresh));
-	if (g_strcmp0 (entry->key, GPK_CONF_SESSION_STARTUP_TIMEOUT) == 0 ||
-	    g_strcmp0 (entry->key, GPK_CONF_FORCE_GET_UPDATES_LOGIN) == 0 ||
-	    g_strcmp0 (entry->key, GPK_CONF_FREQUENCY_GET_UPDATES) == 0 ||
-	    g_strcmp0 (entry->key, GPK_CONF_FREQUENCY_GET_UPGRADES) == 0 ||
-	    g_strcmp0 (entry->key, GPK_CONF_FREQUENCY_REFRESH_CACHE) == 0 ||
-	    g_strcmp0 (entry->key, GPK_CONF_AUTO_UPDATE) == 0 ||
-	    g_strcmp0 (entry->key, GPK_CONF_UPDATE_BATTERY) == 0)
+	if (g_strcmp0 (key, GPK_SETTINGS_SESSION_STARTUP_TIMEOUT) == 0 ||
+	    g_strcmp0 (key, GPK_SETTINGS_FORCE_GET_UPDATES_LOGIN) == 0 ||
+	    g_strcmp0 (key, GPK_SETTINGS_FREQUENCY_GET_UPDATES) == 0 ||
+	    g_strcmp0 (key, GPK_SETTINGS_FREQUENCY_GET_UPGRADES) == 0 ||
+	    g_strcmp0 (key, GPK_SETTINGS_FREQUENCY_REFRESH_CACHE) == 0 ||
+	    g_strcmp0 (key, GPK_SETTINGS_AUTO_UPDATE) == 0 ||
+	    g_strcmp0 (key, GPK_SETTINGS_UPDATE_BATTERY) == 0)
 		gpk_auto_refresh_change_state (arefresh);
 }
 
@@ -445,7 +428,7 @@ gpk_auto_refresh_session_idle_changed_cb (GpkSession *session, gboolean is_idle,
 {
 	g_return_if_fail (GPK_IS_AUTO_REFRESH (arefresh));
 
-	egg_debug ("setting is_idle %i", is_idle);
+	g_debug ("setting is_idle %i", is_idle);
 	arefresh->priv->session_idle = is_idle;
 	if (arefresh->priv->session_idle)
 		gpk_auto_refresh_change_state (arefresh);
@@ -478,14 +461,14 @@ gpk_auto_refresh_convert_network_state (GpkAutoRefresh *arefresh, PkNetworkEnum
 
 	/* check policy */
 	if (state == PK_NETWORK_ENUM_MOBILE)
-		return gconf_client_get_bool (arefresh->priv->gconf_client, GPK_CONF_CONNECTION_USE_MOBILE, NULL);
+		return g_settings_get_boolean (arefresh->priv->settings, GPK_SETTINGS_CONNECTION_USE_MOBILE);
 
 	/* check policy */
 	if (state == PK_NETWORK_ENUM_WIFI)
-		return gconf_client_get_bool (arefresh->priv->gconf_client, GPK_CONF_CONNECTION_USE_WIFI, NULL);
+		return g_settings_get_boolean (arefresh->priv->settings, GPK_SETTINGS_CONNECTION_USE_WIFI);
 
 	/* not recognised */
-	egg_warning ("state unknown: %i", state);
+	g_warning ("state unknown: %i", state);
 	return TRUE;
 }
 
@@ -501,7 +484,7 @@ gpk_auto_refresh_notify_network_state_cb (PkControl *control, GParamSpec *pspec,
 
 	g_object_get (control, "network-state", &state, NULL);
 	arefresh->priv->network_active = gpk_auto_refresh_convert_network_state (arefresh, state);
-	egg_debug ("setting online %i", arefresh->priv->network_active);
+	g_debug ("setting online %i", arefresh->priv->network_active);
 	if (arefresh->priv->network_active)
 		gpk_auto_refresh_change_state (arefresh);
 }
@@ -517,7 +500,7 @@ gpk_auto_refresh_timeout_cb (gpointer user_data)
 	g_return_val_if_fail (GPK_IS_AUTO_REFRESH (arefresh), FALSE);
 
 	/* debug so we can catch polling */
-	egg_debug ("polling check");
+	g_debug ("polling check");
 
 	/* triggered once an hour */
 	gpk_auto_refresh_change_state (arefresh);
@@ -530,21 +513,21 @@ gpk_auto_refresh_timeout_cb (gpointer user_data)
  * gpk_auto_refresh_client_changed_cb:
  **/
 static void
-gpk_auto_refresh_client_changed_cb (DkpClient *client, GpkAutoRefresh *arefresh)
+gpk_auto_refresh_client_changed_cb (UpClient *client, GpkAutoRefresh *arefresh)
 {
 	gboolean on_battery;
 
 	g_return_if_fail (GPK_IS_AUTO_REFRESH (arefresh));
 
 	/* get the on-battery state */
-	on_battery = dkp_client_on_battery (arefresh->priv->client);
+	on_battery = up_client_get_on_battery (arefresh->priv->client);
 	if (on_battery == arefresh->priv->on_battery) {
-		egg_debug ("same state as before, ignoring");
+		g_debug ("same state as before, ignoring");
 		return;
 	}
 
 	/* save in local cache */
-	egg_debug ("setting on_battery %i", on_battery);
+	g_debug ("setting on_battery %i", on_battery);
 	arefresh->priv->on_battery = on_battery;
 	if (!on_battery)
 		gpk_auto_refresh_change_state (arefresh);
@@ -565,7 +548,7 @@ gpk_auto_refresh_get_properties_cb (GObject *object, GAsyncResult *res, GpkAutoR
 	ret = pk_control_get_properties_finish (control, res, &error);
 	if (!ret) {
 		/* TRANSLATORS: backend is broken, and won't tell us what it supports */
-		egg_warning ("could not get properties");
+		g_warning ("could not get properties");
 		g_error_free (error);
 		goto out;
 	}
@@ -591,17 +574,12 @@ gpk_auto_refresh_init (GpkAutoRefresh *arefresh)
 	arefresh->priv->network_active = FALSE;
 	arefresh->priv->force_get_updates_login = FALSE;
 	arefresh->priv->timeout_id = 0;
+	arefresh->priv->periodic_id = 0;
 	arefresh->priv->force_get_updates_login_timeout_id = 0;
 
 	/* we need to know the updates frequency */
-	arefresh->priv->gconf_client = gconf_client_get_default ();
-
-	/* watch gnome-packagekit keys */
-	gconf_client_add_dir (arefresh->priv->gconf_client, GPK_CONF_DIR,
-			      GCONF_CLIENT_PRELOAD_NONE, NULL);
-	gconf_client_notify_add (arefresh->priv->gconf_client, GPK_CONF_DIR,
-				 (GConfClientNotifyFunc) gpk_auto_refresh_gconf_key_changed_cb,
-				 arefresh, NULL, NULL);
+	arefresh->priv->settings = g_settings_new (GPK_SETTINGS_SCHEMA);
+	g_signal_connect (arefresh->priv->settings, "changed", G_CALLBACK (gpk_auto_refresh_key_changed_cb), arefresh);
 
 	/* we need to query the last cache refresh time */
 	arefresh->priv->control = pk_control_new ();
@@ -611,14 +589,14 @@ gpk_auto_refresh_init (GpkAutoRefresh *arefresh)
 	/* get network state */
 	pk_control_get_properties_async (arefresh->priv->control, NULL, (GAsyncReadyCallback) gpk_auto_refresh_get_properties_cb, arefresh);
 
-	/* use a DkpClient */
-	arefresh->priv->client = dkp_client_new ();
+	/* use a UpClient */
+	arefresh->priv->client = up_client_new ();
 	g_signal_connect (arefresh->priv->client, "changed",
 			  G_CALLBACK (gpk_auto_refresh_client_changed_cb), arefresh);
 
 	/* get the battery state */
-	arefresh->priv->on_battery = dkp_client_on_battery (arefresh->priv->client);
-	egg_debug ("setting on battery %i", arefresh->priv->on_battery);
+	arefresh->priv->on_battery = up_client_get_on_battery (arefresh->priv->client);
+	g_debug ("setting on battery %i", arefresh->priv->on_battery);
 
 	/* use gnome-session for the idle detection */
 	arefresh->priv->session = gpk_session_new ();
@@ -627,7 +605,10 @@ gpk_auto_refresh_init (GpkAutoRefresh *arefresh)
 	arefresh->priv->session_idle = gpk_session_get_idle (arefresh->priv->session);
 
 	/* we check this in case we miss one of the async signals */
-	g_timeout_add_seconds (GPK_AUTO_REFRESH_PERIODIC_CHECK, gpk_auto_refresh_timeout_cb, arefresh);
+	arefresh->priv->periodic_id =
+		g_timeout_add_seconds (GPK_AUTO_REFRESH_PERIODIC_CHECK,
+				       gpk_auto_refresh_timeout_cb, arefresh);
+	g_source_set_name_by_id (arefresh->priv->periodic_id, "[GpkAutoRefresh] periodic check");
 
 	/* check system state */
 	gpk_auto_refresh_change_state (arefresh);
@@ -649,11 +630,13 @@ gpk_auto_refresh_finalize (GObject *object)
 
 	if (arefresh->priv->timeout_id != 0)
 		g_source_remove (arefresh->priv->timeout_id);
+	if (arefresh->priv->periodic_id != 0)
+		g_source_remove (arefresh->priv->periodic_id);
 	if (arefresh->priv->force_get_updates_login_timeout_id != 0)
 		g_source_remove (arefresh->priv->force_get_updates_login_timeout_id);
 
 	g_object_unref (arefresh->priv->control);
-	g_object_unref (arefresh->priv->gconf_client);
+	g_object_unref (arefresh->priv->settings);
 	g_object_unref (arefresh->priv->client);
 	g_object_unref (arefresh->priv->session);
 
